@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2011 Aurimas Cernius
+ * Copyright (C) 2010-2012 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -44,6 +44,7 @@
 #include <gtkmm/treemodelsort.h>
 #include <gtkmm/treepath.h>
 #include <gtkmm/treeview.h>
+#include <gtkmm/applicationwindow.h>
 
 #include "note.hpp"
 #include "tag.hpp"
@@ -56,8 +57,10 @@ namespace gnote {
   }
   class NoteManager;
 
+typedef utils::ForcedPresentWindow<Gtk::ApplicationWindow> NoteRecentChangesParent;
+
 class NoteRecentChanges
-  : public utils::ForcedPresentWindow
+  : public NoteRecentChangesParent
 {
 public:
   static NoteRecentChanges *get_instance();
