@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2011 Aurimas Cernius
+ * Copyright (C) 2010-2012 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -28,8 +28,6 @@
 #include <config.h>
 #endif
 
-#include <pcrecpp.h>
-
 #if FIXED_GTKSPELL
 extern "C" {
 #include <gtkspell/gtkspell.h>
@@ -157,7 +155,7 @@ namespace gnote {
 
     NoteTag::Ptr                m_url_tag;
     Glib::RefPtr<Gtk::TextMark> m_click_mark;
-    pcrecpp::RE                 m_regex;
+    Glib::RefPtr<Glib::Regex>   m_regex;
     static const char * URL_REGEX;
     static bool  s_text_event_connected;
   };
@@ -213,7 +211,7 @@ namespace gnote {
 
   protected:
     NoteWikiWatcher()
-      : m_regex(WIKIWORD_REGEX, pcrecpp::RE_Options(PCRE_UTF8))
+      : m_regex(Glib::Regex::create(WIKIWORD_REGEX))
       {
       }
   private:
@@ -225,7 +223,7 @@ namespace gnote {
 
     static const char * WIKIWORD_REGEX;
     Glib::RefPtr<Gtk::TextTag>   m_broken_link_tag;
-    pcrecpp::RE         m_regex;
+    Glib::RefPtr<Glib::Regex>    m_regex;
     sigc::connection    m_on_insert_text_cid;
     sigc::connection    m_on_delete_range_cid;
   };
